@@ -1,8 +1,5 @@
 package App::Metabase::Relayd::Plugin::IRC;
-BEGIN {
-  $App::Metabase::Relayd::Plugin::IRC::VERSION = '0.04';
-}
-
+$App::Metabase::Relayd::Plugin::IRC::VERSION = '0.06';
 # ABSTRACT: IRC plugin for metabase-relayd
 
 use strict;
@@ -57,7 +54,7 @@ sub irc_001 {
 sub _get_channels {
   my $channels = shift;
   my @channels;
-  unless ( $channels ) { 
+  unless ( $channels ) {
     push @channels, '#relayd';
   }
   else {
@@ -68,7 +65,15 @@ sub _get_channels {
 
 sub mbrd_received {
   my ($kernel,$heap,$data,$ip) = @_[KERNEL,HEAP,ARG0,ARG1];
-  my $msg = join(' ', uc($data->{grade}), ( map { $data->{$_} } qw(distfile archname osversion) ), "perl-" . $data->{perl_version} );
+  use Time::Piece;
+  my $stamp = '[ ';
+  {
+    my $t = localtime;
+    $stamp .= join ' ', $ip, $t->strftime("%Y-%m-%dT%H:%M:%S");
+  }
+  $stamp .= ' ]';
+  my $t = localtime; my $ts = $t->strftime("%Y-%m-%dT%H:%M:%S");
+  my $msg = join(' ', uc($data->{grade}), ( map { $data->{$_} } qw(distfile archname osversion) ), "perl-" . $data->{perl_version}, $stamp );
   $heap->{_irc}->yield( 'privmsg', $_, $msg ) for _get_channels( $heap->{channels} );
   return;
 }
@@ -76,30 +81,32 @@ sub mbrd_received {
 
 qq[Smokey IRC];
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::Metabase::Relayd::Plugin::IRC - IRC plugin for metabase-relayd
 
 =head1 VERSION
 
-version 0.04
+version 0.06
 
 =head1 SYNOPSIS
 
   # example metabase-relayd configuration file
 
   [IRC]
-  
+
   server = my.irc.server
   nick = myrelayd
 
 =head1 DESCRIPTION
 
-App::Metabase::Relayd::Plugin::IRC is an IRC plugin for L<App::Metabase::Relayd> and 
+App::Metabase::Relayd::Plugin::IRC is an IRC plugin for L<App::Metabase::Relayd> and
 L<metabase-relayd> that announces on IRC channels when reports are received by the daemon.
 
 Configuration is handled by a section in the L<metabase-relayd> configuration file.
@@ -162,10 +169,9 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Chris Williams.
+This software is copyright (c) 2014 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
